@@ -54,6 +54,7 @@ my $configure_gnusocial=sub {
    my $site_name=$_[7]||'';
    my $site_profile=$_[8]||'';
    my $site_build=$_[9]||'';
+   $service_and_cert_password=$_[10]||'';
    if ($site_profile=~/Commmunity/) {
       $site_profile='community';
    } elsif ($site_profile=~/Public/) {
@@ -64,7 +65,7 @@ my $configure_gnusocial=sub {
       $site_profile='private';
    }
    $permanent_ip='' if $permanent_ip=~/Stay|Reason/;
-   if ($permanent_ip=~/Elastic/ && exists $main::aws->{permanent_ip}) {
+   if (exists $main::aws->{permanent_ip}) {
       $permanent_ip=$main::aws->{permanent_ip}; 
    }
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
@@ -555,7 +556,7 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
          } elsif (!$second_pass) {
             $handle->{_cmd_handle}->print(
                'GRANT USAGE ON gnusocial.* TO gnusocial@localhost'.
-               ' IDENTIFIED BY \'goodrandompassword\';');
+               ' IDENTIFIED BY \'$service_and_cert_password\';');
             $second_pass=1;
          } elsif (!$third_pass) {
             $handle->{_cmd_handle}->print(
@@ -920,6 +921,7 @@ my $standup_gnusocial=sub {
    my $site_name="]I[{'gnusocial_enter_site_name',1}";
    my $site_profile="]T[{choose_site_profile}";
    my $site_build="]T[{choose_build}";
+   my $strong_password="]I[{'gnusocial_enter_password',1}";
    #if (-1<index $site_name, ']T[') {
    #   $site_name="]I[{'gnusocial_enter_domain_name',1}"; 
    #}
@@ -972,13 +974,15 @@ my $standup_gnusocial=sub {
       if ($#{$main::aws->{'GNU.io/Social'}}==0) {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
          $configure_gnusocial,'',$region,$verified_email,
-         $permanent_ip,$site_name,$site_profile,$site_build);
+         $permanent_ip,$site_name,$site_profile,$site_build,
+         $strong_password);
       } else {
          my $num=$#{$main::aws->{'GNU.io/Social'}}-1;
          foreach my $num (0..$num) {
             launch_server('GNU.io/Social',$cnt++,$gnusocial,'',$c,
             $configure_gnusocial,'',$region,$verified_email,
-            $permanent_ip,$site_name,$site_profile,$site_build);
+            $permanent_ip,$site_name,$site_profile,$site_build,
+            $strong_password);
          }
       }
    }
@@ -1096,6 +1100,14 @@ END
 
 our $check_elastic_ip=sub {
 
+   my $password="]I[{'gnusocial_enter_password',1}";
+   my $confirm="]I[{'gnusocial_enter_password',2}";
+   unless ($password eq $confirm) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: Password entries do not match!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   }
    my $c="aws ec2 describe-addresses";
    my ($hash,$output,$error)=run_aws_cmd($c);
    $hash||={};$hash->{Addresses}||=[];
@@ -1302,7 +1314,8 @@ END
    my $email_message={
 
       Name => 'email_message',
-      Result => $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
+      Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_strong_password,
       Banner => $inform_banner,
 
    };
@@ -1310,6 +1323,68 @@ END
 
 };
 
+our $gnusocial_choose_strong_password=sub {
+
+   package choose_strong_password;
+   my $gnusocial_password_banner=<<'END';
+
+    ___ _                       ___                              _
+   / __| |_ _ _ ___ _ _  __ _  | _ \__ _ _______ __ _____ _ _ __| |
+   \__ \  _| '_/ _ \ ' \/ _` | |  _/ _` (_-<_-< V  V / _ \ '_/ _` |
+   |___/\__|_| \___/_||_\__, | |_| \__,_/__/__/\_/\_/\___/_| \__,_|
+                        |___/
+
+END
+   use Crypt::GeneratePassword qw(word);
+   my $word='';
+   foreach my $count (1..10) {
+      print "\n   Generating Password ...\n";
+      $word=eval {
+         local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
+         alarm 7;
+         my $word=word(10,15,3,5,6);
+         print "\n   Trying Password - $word ...\n";
+         die if -1<index $word,'*';
+         die if -1<index $word,'$';
+         die if -1<index $word,'+';
+         return $word;
+      };
+      alarm 0;
+      last if $word;
+   }
+   $gnusocial_password_banner.=<<END;
+   Database (MariaDB), Web Server (NGINX) and SSL Certificate need a strong
+   password. Use the one supplied here, or create your own. To create
+   your own, use the [DEL] key to clear the highlighted input box first.
+
+   *** BE SURE TO WRITE IT DOWN AND KEEP IT SOMEWHERE SAFE! ***
+
+   Input box with === border is highlighted (active) input box.
+   Use [TAB] key to switch focus between input boxes.
+
+
+   Password
+                    ]I[{1,\'$word\',50}
+
+   Confirm
+                    ]I[{2,\'$word\',50}
+
+
+END
+   my $gnusocial_enter_password={
+
+      Name => 'gnusocial_enter_password',
+      Input => 1,
+      Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
+      #Result => $gnusocial_setup_summary,
+      Banner => $gnusocial_password_banner,
+
+   };
+   return $gnusocial_enter_password;
+
+};
+
 our $gnusocial_enter_email_address=sub {
 
    my $gnusocial_email_banner=<<'END';
@@ -1398,7 +1473,7 @@ END
             Text => "]C[",
             Convey => \@identities,
             Result =>
-               $Net::FullAuto::ISets::Amazon::GNUSocial_is::check_elastic_ip,
+         $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_strong_password,
 
          },
          Scroll => 2,
@@ -1508,6 +1583,34 @@ END
 
 our $gnusocial_enter_site_name=sub {
 
+   package gnusocial_enter_site_name;
+   my $permanent_ip="]T[{permanent_ip}";
+   if ($permanent_ip=~/^["]Release.* (\d+\.\d+\.\d+\.\d+).*$/s) {
+      my $ip_to_release=$1;
+      my $c="aws ec2 describe-addresses";
+      my ($hash,$output,$error)=
+         &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+      $hash||={};$hash->{Addresses}||=[];
+      foreach my $address (@{$hash->{Addresses}}) {
+         if ($address->{PublicIp} eq $ip_to_release) {
+            my $c="aws ec2 release-address ".
+                  "--allocation-id $address->{AllocationId}";
+            my ($hash,$output,$error)=
+               &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+            last;
+         }
+      }
+      print "\n   $ip_to_release HAS BEEN RELEASED . . .\n";
+      sleep 5;
+   } elsif ($permanent_ip=~/(\d+\.\d+\.\d+\.\d+)/s) {
+      $main::aws->{permanent_ip}=$1;
+   } elsif ($permanent_ip=~/Elastic \(Permanent\)/) {
+      my $c="aws ec2 allocate-address --domain vpc";
+      my ($hash,$output,$error)=
+            &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
+      $hash||={};
+      $main::aws->{permanent_ip}=$hash->{PublicIp};
+   }
    my $gnusocial_site_banner=<<'END';
 
     ___     _             ___ _ _         _  _
@@ -1540,7 +1643,8 @@ END
       Name => 'gnusocial_enter_site_name',
       Input => 1,
       #Result => $gnusocial_validate_domain,
-      Result => $gnusocial_choose_site_profile,
+      Result => 
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_site_profile,
       Banner => $gnusocial_site_banner,
 
    };
